translate.storage.csvl10n.DefaultDialect

Package translate :: Package storage :: Module csvl10n :: Class DefaultDialect |
[hide private]
[frames] | no frames]

# Class DefaultDialect

source code

Instance Methods | [hide private]
Inherited from `csv.Dialect`: `__init__` Inherited from `csv.Dialect` (private): `_validate`

Class Variables | [hide private]
| skipinitialspace = `True` hash(x)
| quoting = `csv.QUOTE_NONNUMERIC` hash(x)
| escapechar = `'\\'` hash(x)
Inherited from `csv.excel`: `delimiter`, `doublequote`, `lineterminator`, `quotechar` Inherited from `csv.Dialect` (private): `_name`, `_valid`